@@ -733,11 +733,20 @@ void ContainmentItem::loadWallpaper()
         // Qml seems happier if the parent gets set in this way
         m_wallpaperItem->setProperty("parent", QVariant::fromValue(this));
 
-        connect(m_wallpaperItem, &WallpaperItem::isLoadingChanged, this, [this]() {
-            if (!isLoading()) {
-                applet()->updateConstraints(Plasma::Applet::UiReadyConstraint);
-            }
-        });
+        if (isLoading()) {
+            connect(
+                m_wallpaperItem,
+                &WallpaperItem::isLoadingChanged,
+                this,
+                [this]() {
+                    if (!isLoading()) {
+                        applet()->updateConstraints(Plasma::Applet::UiReadyConstraint);
+                    }
+                },
+                Qt::SingleShotConnection);
+        } else {
+            applet()->updateConstraints(Plasma::Applet::UiReadyConstraint);
+        }
 
         // set anchors
         QQmlExpression expr(qmlObject()->engine()->rootContext(), m_wallpaperItem, QStringLiteral("parent"));
@@ -1037,7 +1046,6 @@ void ContainmentItem::addContainmentActions(QMenu *desktopMenu, QEvent *event)
 
 bool ContainmentItem::isLoading() const
 {
-    return false;
     return m_wallpaperItem && m_wallpaperItem->isLoading();
 }
 
